@@ -1,26 +1,27 @@
 """
 peakrdl-python is a tool to generate Python Register Access Layer (RAL) from SystemRDL
-Copyright (C) 2021 - 2023
+Copyright (C) 2021 - 2025
 
 This program is free software: you can redistribute it and/or modify
-it under the terms of the GNU General Public License as published by
-the Free Software Foundation, either version 3 of the License, or
-(at your option) any later version.
+it under the terms of the GNU Lesser General Public License as 
+published by the Free Software Foundation, either version 3 of 
+the License, or (at your option) any later version.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-GNU General Public License for more details.
+GNU Lesser General Public License for more details.
 
-You should have received a copy of the GNU General Public License
+You should have received a copy of the GNU Lesser General Public License
 along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 Node walkers to be used in the generated of the output code
 """
-from typing import Optional, List, Union, Iterator
+from typing import Optional, Union
+from collections.abc import Iterator
 
-from systemrdl import RDLListener, WalkerAction # type: ignore
-from systemrdl.node import RegNode, MemNode, FieldNode, AddrmapNode, RegfileNode # type: ignore
+from systemrdl import RDLListener, WalkerAction
+from systemrdl.node import RegNode, MemNode, FieldNode, AddrmapNode, RegfileNode
 
 from .systemrdl_node_utility_functions import HideNodeCallback
 
@@ -32,7 +33,7 @@ class AddressMaps(RDLListener):
     """
     def __init__(self, hide_node_callback: HideNodeCallback) -> None:
         super().__init__()
-        self.__address_maps: List[AddrmapNode] = []
+        self.__address_maps: list[AddrmapNode] = []
         self.__hide_node_callback = hide_node_callback
 
     def enter_Addrmap(self, node: AddrmapNode) -> Optional[WalkerAction]:
@@ -50,21 +51,21 @@ class AddressMaps(RDLListener):
 class OwnedbyAddressMap(RDLListener):
     """
     class intended to be used as part of the walker/listener protocol to find all the items owned
-    by an address map but not the descendents of any address map
+    by an address map but not the descendants of any address map
     """
     def __init__(self, hide_node_callback: HideNodeCallback) -> None:
         super().__init__()
 
-        self.registers: List[RegNode] = []
-        self.fields: List[RegNode] = []
-        self.memories: List[RegNode] = []
-        self.addr_maps: List[AddrmapNode] = []
-        self.reg_files: List[RegfileNode] = []
-        self._hidden_registers: List[RegNode] = []
-        self._hidden_fields: List[RegNode] = []
-        self._hidden_memories: List[RegNode] = []
-        self._hidden_addr_maps: List[AddrmapNode] = []
-        self._hidden_reg_files: List[RegfileNode] = []
+        self.registers: list[RegNode] = []
+        self.fields: list[FieldNode] = []
+        self.memories: list[MemNode] = []
+        self.addr_maps: list[AddrmapNode] = []
+        self.reg_files: list[RegfileNode] = []
+        self._hidden_registers: list[RegNode] = []
+        self._hidden_fields: list[FieldNode] = []
+        self._hidden_memories: list[MemNode] = []
+        self._hidden_addr_maps: list[AddrmapNode] = []
+        self._hidden_reg_files: list[RegfileNode] = []
         self.__hide_node_callback = hide_node_callback
 
     def enter_Reg(self, node: RegNode) -> Optional[WalkerAction]:
@@ -107,7 +108,7 @@ class OwnedbyAddressMap(RDLListener):
         return WalkerAction.Continue
 
     @property
-    def nodes(self) -> List[Union[RegNode, MemNode, FieldNode, AddrmapNode, RegfileNode]]:
+    def nodes(self) -> list[Union[RegNode, MemNode, FieldNode, AddrmapNode, RegfileNode]]:
         """
         All the nodes owned by the address map, including:
         - address maps
@@ -122,7 +123,7 @@ class OwnedbyAddressMap(RDLListener):
         return self.addr_maps + self.reg_files + self.memories + self.registers + self.fields
 
     @property
-    def hidden_nodes(self) -> List[Union[RegNode, MemNode, FieldNode, AddrmapNode, RegfileNode]]:
+    def hidden_nodes(self) -> list[Union[RegNode, MemNode, FieldNode, AddrmapNode, RegfileNode]]:
         """
         All the 1st tier nodes owned by the address map which are hidden, including:
         - address maps
@@ -145,7 +146,7 @@ class OwnedbyAddressMap(RDLListener):
         return len(self.hidden_nodes) > 0
 
     @property
-    def addressable_nodes(self) -> List[Union[RegNode, MemNode, AddrmapNode, RegfileNode]]:
+    def addressable_nodes(self) -> list[Union[RegNode, MemNode, AddrmapNode, RegfileNode]]:
         """
         All the nodes owned by the address map, including:
         - address maps
